# Please keep this package in sync with FC

%bcond_without docs

%{!?with_crash: %global with_crash 1}

%ifarch %{ix86} x86_64 ppc ppc64 ppc64le aarch64
%{!?with_dyninst: %global with_dyninst 1}
%else
%{!?with_dyninst: %global with_dyninst 0}
%endif
%{!?with_bpf: %global with_bpf 0%{?mageia} >= 6}
%{!?with_virthost: %global with_virthost 0%{?mageia} >= 5}
%{!?with_pyparsing: %global with_pyparsing 0%{?mageia} >= 5}
%{!?with_python2_probes: %global with_python2_probes (0%{?mageia} < 8)}
%{!?with_python3_probes: %global with_python3_probes (0%{?mageia} >= 5)}
%{!?with_java: %global with_java 0%{?mageia} >= 4 }

%define udevrulesdir /usr/lib/udev/rules.d

# To avoid testsuite/*/*.stp has shebang which doesn't start with '/'
%define __brp_mangle_shebangs_exclude_from .stp$

Summary: 	Infrastructure to gather information about the running Linux system
Name: 		systemtap
Epoch:		1
Version: 	4.4
Release: 	%mkrel 4
License: 	GPLv2+
Group: 		Development/Kernel
URL: 		https://sourceware.org/systemtap/
Source:		ftp://sourceware.org/pub/systemtap/releases/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(libcap)
BuildRequires:	elfutils-static-devel
BuildRequires:	pkgconfig(avahi-client)
%if %{with_dyninst}
BuildRequires:	dyninst-devel >= 10.0
%endif
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	systemd
BuildRequires:	crash-devel zlib-devel
%if %{with docs}
BuildRequires:	latex2html
BuildRequires:	texlive-texmf
%endif
BuildRequires:	xmlto
BuildRequires:	pkgconfig(libvirt)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(rpm) >= 4.12.90
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
# compat with FC:
Provides:	systemtap = %{version}-%{release}

%description
SystemTap provides free software (GPL) infrastructure to simplify the gathering
of information about the running Linux system. This assists diagnosis of a
performance or functional problem. SystemTap eliminates the need for the
developer to go through the tedious and disruptive instrument, recompile,
install, and reboot sequence that may be otherwise required to collect data.

SystemTap provides a simple command line interface and scripting language for
writing instrumentation for a live running kernel. We are publishing samples,
as well as enlarging the internal "tapset" script library to aid reuse and
abstraction. We also plan to support probing userspace applications. We are
investigating interfacing Systemtap with similar tools such as Frysk,
Oprofile and LTT.

%package devel
Summary: Programmable system-wide instrumentation system - development headers, tools
License: GPLv2+
URL: https://sourceware.org/systemtap/

Recommends: kernel-desktop-devel

Requires: gcc make
Conflicts: systemtap-client < %{version}-%{release}
Conflicts: systemtap-server < %{version}-%{release}
Conflicts: systemtap-runtime < %{version}-%{release}
# Suggest: kernel-debuginfo
# mga7 -> mga8 upgrade:
Conflicts: %name < 3.2-2.1.mga8
# compat with FC:
Provides: systemtap-devel = %{version}-%{release}

%description devel
This package contains the components needed to compile a systemtap
script from source form into executable (.ko) forms.  It may be
installed on a self-contained developer workstation (along with the
systemtap-client and systemtap-runtime packages), or on a dedicated
remote server (alongside the systemtap-server package).  It includes
a copy of the standard tapset library and the runtime library C files.



%package sdt-devel
Summary: Static probe support tools
License: GPLv2+ and Public Domain
URL: https://sourceware.org/systemtap/
%if %{with_pyparsing}
Requires: python3-pyparsing
%endif
# mga7 -> mga8 upgrade:
Conflicts: %name < 4.2-2.1.mga8
# compat with FC:
Provides: systemtap-sdt-devel = %{version}-%{release}

%description sdt-devel
This package includes the <sys/sdt.h> header file used for static
instrumentation compiled into userspace programs and libraries, along
with the optional dtrace-compatibility preprocessor to process related
.d files into tracing-macro-laden .h headers.
 
 
%package testsuite
Summary: Instrumentation System Testsuite
License: GPLv2+
URL: https://sourceware.org/systemtap/
Requires: systemtap = %{version}-%{release}
Requires: systemtap-devel = %{version}-%{release}
Requires: systemtap-sdt-devel = %{version}-%{release}
Requires: dejagnu which elfutils grep netcat
Requires: gcc gcc-c++ make glibc-devel
# testsuite/systemtap.base/ptrace.exp needs strace
Requires: strace
# testsuite/systemtap.base/ipaddr.exp needs nc. Unfortunately, the rpm
# that provides nc has changed over time (from 'nc' to
# 'nmap-ncat'). So, we'll do a file-based require.
Requires: netcat
# testsuite/systemtap.server/client.exp needs avahi
Requires: avahi
%if %{with_crash}
# testsuite/systemtap.base/crash.exp needs crash
Requires: crash
%endif
%if %{with_python3_probes}
Requires: systemtap-runtime-python3 = %{version}-%{release}
%endif
%ifarch x86_64
Requires: glibc-devel
#Requires: /usr/lib/libc.so
# ... and /usr/lib/libgcc_s.so.*
# ... and /usr/lib/libstdc++.so.*
%endif
Requires: stress
# The following "meta" files for the systemtap examples run "perf":
#   testsuite/systemtap.examples/hw_watch_addr.meta
#   testsuite/systemtap.examples/memory/hw_watch_sym.meta
Requires: perf
 
%description testsuite
This package includes the dejagnu-based systemtap stress self-testing
suite.  This may be used by system administrators to thoroughly check
systemtap on the current system.

%package runtime-python3
Summary: Systemtap Python 3 Runtime Support
Group: Development/Python
License: GPLv2+
URL: https://sourceware.org/systemtap/
Requires: systemtap = %{version}-%{release}
# compat with FC:
Provides: systemtap-runtime-python3 = %{version}-%{release}

%description runtime-python3
This package includes support files needed to run systemtap scripts
that probe python 3 processes.

%package exporter
Summary: Systemtap-prometheus interoperation mechanism
Group: Development/Kernel
License: GPLv2+
URL: https://sourceware.org/systemtap/

%description exporter
This package includes files for a systemd service that manages
systemtap sessions and relays prometheus metrics from the sessions
to remote requesters on demand.

%if %{with_virthost}
%package runtime-virthost
Summary: Systemtap Cross-VM Instrumentation - host
License: GPLv2+
URL: https://sourceware.org/systemtap/
# pulls libvirt:
Requires: libvirt-utils >= 1.0.2
# mga7 -> mga8 upgrade:
Conflicts: %name < 4.2-2.1.mga8

%description runtime-virthost
This package includes the components required to run systemtap scripts
inside a libvirt-managed domain from the host without using a network
connection.
%endif
 
%package runtime-virtguest
Summary: Systemtap Cross-VM Instrumentation - guest
Group: Development/Kernel
License: GPLv2+
URL: https://sourceware.org/systemtap/
Requires(post): findutils coreutils
Requires(preun): grep coreutils
Requires(postun): grep coreutils

%description runtime-virtguest
This package installs the services necessary on a virtual machine for a
systemtap-runtime-virthost machine to execute systemtap scripts.

%prep
%setup -q

%build
# Enable/disable the dyninst pure-userspace backend
%if %{with_dyninst}
%global dyninst_config --with-dyninst
%else
%global dyninst_config --without-dyninst
%endif
%configure %{dyninst_config} \
	--with-bpf \
	--with-rpm \
	--without-python2-probes \
	--with-python3 \
	--%{?with_docs:enable}%{?!with_docs:disable}-docs
%make_build

%install
%make_install
%find_lang %{name} --all-name --with-man

# To make rpmlint happy, remove any .gitignore files in the testsuite.
find testsuite -type f -name '.gitignore' -print0 | xargs -0 rm -f

# Copy over the testsuite
cp -rp testsuite $RPM_BUILD_ROOT%{_datadir}/systemtap

install -D -m 644 macros.systemtap $RPM_BUILD_ROOT%{_rpmmacrodir}/macros.systemtap

# If using systemd systemtap.service file, retain the old init script in %{_libexecdir} as a helper.
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
touch $RPM_BUILD_ROOT%{_unitdir}/systemtap.service
install -m 644 initscript/systemtap.service $RPM_BUILD_ROOT%{_unitdir}/systemtap.service
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
install -m 755 initscript/systemtap $RPM_BUILD_ROOT%{_sbindir}/systemtap-service

   mkdir -p $RPM_BUILD_ROOT%{udevrulesdir}
      install -p -m 644 staprun/guest/99-stapsh.rules $RPM_BUILD_ROOT%{udevrulesdir}
      mkdir -p $RPM_BUILD_ROOT%{_unitdir}
      install -p -m 644 staprun/guest/stapsh@.service $RPM_BUILD_ROOT%{_unitdir}

# Some files got ambiguous python shebangs, we fix them after everything else is done
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" %{buildroot}%{python3_sitearch} %{buildroot}%{_bindir}/*

%post runtime-virtguest
   # Start services if there are ports present
   if [ -d /dev/virtio-ports ]; then
      (find /dev/virtio-ports -iname 'org.systemtap.stapsh.[0-9]*' -type l \
         | xargs -n 1 basename \
         | xargs -n 1 -I {} /bin/systemctl start stapsh@{}.service) >/dev/null 2>&1 || :
   fi
exit 0

%files
%{_unitdir}/systemtap.service
%{_sbindir}/systemtap-service
%doc AUTHORS HACKING README runtime/docs/examples
%if %{with docs}
%doc doc/langref.pdf doc/tutorial.pdf
%doc %{_docdir}/%{name}/tapsets.pdf
%doc %{_docdir}/%{name}/SystemTap_Beginners_Guide.pdf
%endif
%exclude %{_bindir}/stapvirt
%{_bindir}/stap*
%{_mandir}/man1/stap{-merge,ref}*
%{_mandir}/man3/*
%{_mandir}/man8/*
%{_libexecdir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/systemtap/examples
%{_datadir}/systemtap/runtime
%{_datadir}/systemtap/tapset

%files devel -f systemtap.lang
%{_bindir}/stap
#{_bindir}/stap-prep
%{_bindir}/stap-report
%dir %{_datadir}/systemtap
%{_datadir}/systemtap/runtime
%{_datadir}/systemtap/tapset
%{_mandir}/man1/stap.1*
%{_mandir}/man1/stap-prep.1*
%{_mandir}/man1/stap-report.1*
%{_mandir}/man7/error*
%{_mandir}/man7/stappaths.7*
%{_mandir}/man7/warning*
%doc README README.unprivileged AUTHORS NEWS 
%{!?_licensedir:%global license %%doc}
%license COPYING
%if %{with_java}
%dir %{_libexecdir}/systemtap
# %{_libexecdir}/systemtap/libHelperSDT_*.so
%endif
# Notice that the stap-resolve-module-function.py file is used by
# *both* the python2 and python3 subrpms.  Both subrpms use that same
# python script to help list python probes.
%if %{with_python3_probes} || %{with_python2_probes}
%{_libexecdir}/systemtap/python/stap-resolve-module-function.py
%exclude %{_libexecdir}/systemtap/python/stap-resolve-module-function.py?
%endif



%files sdt-devel
%{_bindir}/dtrace
%{_includedir}/sys/sdt.h
%{_includedir}/sys/sdt-config.h
%{_mandir}/man1/dtrace.1*
%{_rpmmacrodir}/macros.systemtap
%doc README AUTHORS NEWS 
%license COPYING


%files testsuite
%dir %{_datadir}/systemtap
%{_datadir}/systemtap/testsuite

%files runtime-python3
%{python3_sitearch}/HelperSDT
%{python3_sitearch}/HelperSDT-*.egg-info

%if %{with_virthost}
%files runtime-virthost
%{_mandir}/man1/stapvirt.1*
%{_bindir}/stapvirt
%endif

%files runtime-virtguest
   %{udevrulesdir}/99-stapsh.rules
   %{_unitdir}/stapsh@.service

%files exporter
%{_sysconfdir}/stap-exporter
%{_sysconfdir}/sysconfig/stap-exporter
%{_unitdir}/stap-exporter.service
%{_mandir}/man8/stap-exporter.8*
%{_sbindir}/stap-exporter


%changelog
* Thu Dec 31 2020 wally <wally> 1:4.4-4.mga8
+ Revision: 1666823
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1:4.4-3.mga8
+ Revision: 1662065
- rebuild for boost 1.74.0

* Sun Nov 29 2020 luigiwalser <luigiwalser> 1:4.4-2.mga8
+ Revision: 1650349
- rebuild for json-c

* Tue Nov 10 2020 tv <tv> 1:4.4-1.mga8
+ Revision: 1644258
- 4.4

* Thu Sep 10 2020 tv <tv> 1:4.3-3.mga8
+ Revision: 1624066
- Rebuild for dyninst 10.2.0

* Wed Sep 09 2020 tv <tv> 1:4.3-2.mga8
+ Revision: 1623997
- Rebuild for dyninst 10.2.0

* Fri Jun 12 2020 tv <tv> 1:4.3-1.mga8
+ Revision: 1593050
- 4.3

* Sun May 03 2020 wally <wally> 1:4.2-5.mga8
+ Revision: 1578119
- rebuild for boost 1.73.0
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 20 2020 umeabot <umeabot> 1:4.2-4.mga8
+ Revision: 1545436
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 mokraemer <mokraemer> 1:4.2-3.mga8
+ Revision: 1484743
- fixed missing files, macro expansion; rebuild for boost
+ wally <wally>
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x
+ tv <tv>
- split devel subpkg
- typo fix
- split runtime-virthost & sdt-devel subpkgs
- split testsuite package

* Sat Jan 04 2020 tv <tv> 1:4.2-2.mga8
+ Revision: 1476450
- fix ambiguous python shebangs
- rebuild for new readline

* Sat Nov 23 2019 tv <tv> 1:4.2-1.mga8
+ Revision: 1462263
- 4.2

* Sun Sep 15 2019 tv <tv> 1:4.1-3.mga8
+ Revision: 1441651
- drop python2 subpkg
- rebuild for python-3.8
- rebuild for rpm-4.15

* Tue Jul 02 2019 tv <tv> 1:4.1-1.mga8
+ Revision: 1417607
- new release
- rebuild for new dyninst

* Thu Feb 07 2019 wally <wally> 1:4.0-5.mga7
+ Revision: 1364033
- prefer python3

* Tue Jan 08 2019 tv <tv> 1:4.0-4.mga7
+ Revision: 1352000
- rebuild with python 3.7
- add runtime-virtguest subpkg

* Mon Oct 15 2018 tv <tv> 1:4.0-2.mga7
+ Revision: 1320389
- enable more features
- enable systemd support
- explicitely enable bpf
- new release

* Sun Sep 23 2018 umeabot <umeabot> 1:3.3-6.mga7
+ Revision: 1301297
- Mageia 7 Mass Rebuild

* Fri Jul 06 2018 pterjan <pterjan> 1:3.3-5.mga7
+ Revision: 1242380
- Restrict dyninst requirement to architectures where it is available

* Thu Jun 14 2018 daviddavid <daviddavid> 1:3.3-4.mga7
+ Revision: 1236919
- add missing epoch

* Thu Jun 14 2018 daviddavid <daviddavid> 1:3.3-3.mga7
+ Revision: 1236844
- fix requires

* Wed Jun 13 2018 tv <tv> 1:3.3-2.mga7
+ Revision: 1236736
- add python subpkgs
- new version

* Tue Jan 02 2018 wally <wally> 1:3.2-0.2.mga7
+ Revision: 1189474
- rebuild for new readline

* Fri Sep 08 2017 tv <tv> 1:3.2-0.1.mga7
+ Revision: 1151927
- new release (needed in order to fix qemu build with gcc7) [gcc#PR80115]

* Fri Sep 01 2017 tv <tv> 1:3.1-2.mga7
+ Revision: 1150528
- patch 2: fix build with new rpm
- rebuild for new rpm

* Tue Feb 21 2017 luigiwalser <luigiwalser> 1:3.1-1.mga6
+ Revision: 1087193
- 3.1

* Sat Feb 04 2017 daviddavid <daviddavid> 1:3.0-3.mga6
+ Revision: 1084796
- use new rpm macros thus fixing installation of all lang manpages

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1:3.0-2.mga6
+ Revision: 1045940
- add patch from fedora with fixes for kernel 4.6
+ tv <tv>
- gtkmm2.4-devel & libglade2.0-devel are unneeded for years

* Mon Mar 28 2016 luigiwalser <luigiwalser> 1:3.0-1.mga6
+ Revision: 996040
- docs are pdf now
- html docs are not generated for now
- 3.0
- include patch from fedora to fix brown paper bag bug

* Sat Dec 26 2015 luigiwalser <luigiwalser> 1:2.9-1.mga6
+ Revision: 915478
- add systemtap beginners guide to doc list
- 2.9

* Sat Oct 10 2015 blino <blino> 1:2.6-6.mga6
+ Revision: 889400
- buildrequire xmlto and package html doc (build failed when xmlto was installed)

* Sun Sep 06 2015 tv <tv> 1:2.6-5.mga6
+ Revision: 873244
- submit to core/release

* Sun Aug 23 2015 tv <tv> 1:2.6-4.mga6
+ Revision: 868858
- fix "Installed (but unpackaged) file(s)"
- rebuild for rpm-4.13

* Wed Oct 15 2014 umeabot <umeabot> 1:2.6-3.mga5
+ Revision: 740900
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 luigiwalser <luigiwalser> 1:2.6-1.mga5
+ Revision: 674462
- 2.6

* Fri May 09 2014 luigiwalser <luigiwalser> 1:2.5-1.mga5
+ Revision: 621627
- 2.5

* Wed Dec 18 2013 luigiwalser <luigiwalser> 1:2.4-1.mga4
+ Revision: 558636
- 2.4
- fix /usr/share/systemtap directory permissions

* Tue Oct 22 2013 umeabot <umeabot> 1:2.3-5.mga4
+ Revision: 541512
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 dmorgan <dmorgan> 1:2.3-4.mga4
+ Revision: 496062
- Remove workaround now that java7 is fixed

* Sat Oct 12 2013 dmorgan <dmorgan> 1:2.3-3.mga4
+ Revision: 495974
- workaround java conflicts

* Thu Oct 10 2013 luigiwalser <luigiwalser> 1:2.3-2.mga4
+ Revision: 494426
- add BR texlive-texmf to try to fix build

* Fri Aug 09 2013 luigiwalser <luigiwalser> 1:2.3-1.mga4
+ Revision: 464828
- 2.3

* Wed Jul 24 2013 luigiwalser <luigiwalser> 1:2.2.1-1.mga4
+ Revision: 457521
- 2.2.1

* Mon Jan 14 2013 umeabot <umeabot> 1:2.0-4.mga3
+ Revision: 383985
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 pterjan <pterjan> 1:2.0-3.mga3
+ Revision: 340115
- Fix for _libdir != _libexecdir
- Fix file list to own directories

* Tue Dec 18 2012 tv <tv> 1:2.0-2.mga3
+ Revision: 332390
- rebuild for new rpm

* Tue Dec 18 2012 tv <tv> 1:2.0-1.mga3
+ Revision: 332375
- drop obsolete CVE patch
- new release
- rebuild for new rpm

* Tue Jun 12 2012 tv <tv> 1:1.6-6.mga3
+ Revision: 259950
+ rebuild (emptylog)

* Sun Jun 10 2012 tv <tv> 1:1.6-5.mga3
+ Revision: 259377
- rebuild for new rpm-4.10.0

* Mon Apr 09 2012 luigiwalser <luigiwalser> 1:1.6-4.mga2
+ Revision: 230000
- fix CVE-2012-0875 (from redhat)

* Tue Dec 20 2011 dmorgan <dmorgan> 1:1.6-3.mga2
+ Revision: 185014
- Rebuild against rpm 4.9.1.2

* Tue Oct 18 2011 dmorgan <dmorgan> 1:1.6-2.mga2
+ Revision: 156307
- Add rpm-devel as buildrequires
- Add rpm support

* Tue Oct 18 2011 dmorgan <dmorgan> 1:1.6-1.mga2
+ Revision: 156102
- New version 1.6

* Fri Sep 09 2011 tv <tv> 1:1.4-1.mga2
+ Revision: 141642
- new release
- sync patches with fedora
- drop buildroot
+ rtp <rtp>
- disable systemtap on mips as it's not supported

* Wed Jan 12 2011 ahmad <ahmad> 1:1.3-1.mga1
+ Revision: 7722
- imported package systemtap


* Fri Aug 06 2010 trem <trem@mandriva.org> 1:1.3-1mdv2011.0
+ Revision: 566922
- update to 1.3
- update Buildrequires

* Thu Mar 25 2010 trem <trem@mandriva.org> 1:1.2-1mdv2010.1
+ Revision: 527315
- update to 1.2
- remove patch systemtap-1.1-get_argv.patch (added upstream)
- remove patch systemtap-1.1-cfi-cfa_ops-fixes.patch (added upstream)
- remove patch systemtap-1.1-tighten-server-params.patch (added upstream)

* Thu Feb 25 2010 Oden Eriksson <oeriksson@mandriva.com> 1:1.1-2mdv2010.1
+ Revision: 511042
- sync with systemtap-1.1-2.fc13.src.rpm
- P1: security fix for CVE-2010-0411
- P2: security fix for CVE-2010-0412, CVE-2009-4273

  + trem <trem@mandriva.org>
    - update to 1.1
    - remove patch p0, p1 and p2 (CVE-2009-2911) (added upstream)

* Fri Oct 23 2009 Frederic Crozat <fcrozat@mandriva.com> 1:1.0-3mdv2010.0
+ Revision: 459091
- Force rebuild

  + Frederik Himpe <fhimpe@mandriva.org>
    - Add Fedora patches to fix CVE-2009-2911

* Wed Sep 23 2009 Eugeni Dodonov <eugeni@mandriva.com> 1:1.0-1mdv2010.0
+ Revision: 447869
- Updated to 1.0.

* Wed Aug 05 2009 trem <trem@mandriva.org> 1:0.9.9-1mdv2010.0
+ Revision: 410267
- update to 0.9.9

* Fri Jun 12 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 1:0.9.8-1mdv2010.0
+ Revision: 385378
- Updated to version 0.9.8

* Tue May 12 2009 trem <trem@mandriva.org> 0.20090429.1-1mdv2010.0
+ Revision: 375054
- update to 20090429 (0.9.7)
- update to 0.8
- clean .spec (remove useless patch)

* Tue Oct 14 2008 Luiz Fernando Capitulino <lcapitulino@mandriva.com> 0.20081013.1-1mdv2009.1
+ Revision: 293675
- Update to 2008-10-13 version, because of changes in the kernel API

* Wed Jul 09 2008 trem <trem@mandriva.org> 0.20080705.1-1mdv2009.0
+ Revision: 233150
- update to 20080705

* Mon Jul 07 2008 Oden Eriksson <oeriksson@mandriva.com> 0.20080614.1-2mdv2009.0
+ Revision: 232373
- rebuilt against new libcap

* Fri Jun 20 2008 trem <trem@mandriva.org> 0.20080614.1-1mdv2009.0
+ Revision: 227507
- remove useless BuildRequires
- add patches to fix configure (Underlinking problems)
- add Buildrequires:elfutils-devel
- update to 20080614

* Sun May 18 2008 trem <trem@mandriva.org> 0.20080517.1-1mdv2009.0
+ Revision: 208699
- update to 20080517:x
- add testsuite (include some example)

* Sat May 10 2008 trem <trem@mandriva.org> 0.20080510.1-1mdv2009.0
+ Revision: 205404
- update to 20080510
- update to 20080315

* Sun Feb 17 2008 trem <trem@mandriva.org> 0.20080216.1-1mdv2008.1
+ Revision: 170043
- update to 20080216

* Sun Feb 10 2008 trem <trem@mandriva.org> 0.20080209.1-1mdv2008.1
+ Revision: 164875
- update to 20080209

* Sun Jan 27 2008 trem <trem@mandriva.org> 0.20080126.1-1mdv2008.1
+ Revision: 158876
- update to 20080126

* Sun Jan 27 2008 trem <trem@mandriva.org> 0.20080112.1-2mdv2008.1
+ Revision: 158778
- update to 20080112

* Sun Jan 27 2008 trem <trem@mandriva.org> 0.20071208.1-2mdv2008.1
+ Revision: 158756
- fix provide (don't request a lib that don't exist)

* Thu Jan 03 2008 trem <trem@mandriva.org> 0.20071208.1-1mdv2008.1
+ Revision: 143564
- add elfutils-static-devel as buildrequires
- add elfutils and libcap-devel as buildrequires
- add libelfutils-devel as builrequires
- add libcap-devel as Buildrequires
- import systemtap


* Sun Dec  9 2007  <trem@mandriva.org> 0.20071208.1-1mdv2008.1
- Initial build.
